:html_theme.sidebar_secondary.remove:

{{ objname | escape | underline}}

.. currentmodule:: {{ module }}

.. auto{{ objtype }}:: {{ objname }}
    :members:
    :undoc-members:
    :show-inheritance: